km3pipe.db.DOMContainer
=======================

.. currentmodule:: km3pipe.db

.. autoclass:: DOMContainer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DOMContainer.__init__
      ~DOMContainer.clbupi2domid
      ~DOMContainer.clbupi2floor
      ~DOMContainer.domid2floor
      ~DOMContainer.ids
      ~DOMContainer.via_clb_upi
      ~DOMContainer.via_dom_id
      ~DOMContainer.via_omkey
   
   

   
   
   